Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/npm/cli.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'node_modules/debug/src/index.js')
-rw-r--r--node_modules/debug/src/index.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/node_modules/debug/src/index.js b/node_modules/debug/src/index.js
index cabcbcda1..bf4c57f25 100644
--- a/node_modules/debug/src/index.js
+++ b/node_modules/debug/src/index.js
@@ -1,10 +1,10 @@
/**
* Detect Electron renderer process, which is node, but we should
* treat as a browser.
*/
-if (typeof process === 'undefined' || process.type === 'renderer') {
- module.exports = require('./browser.js');
+if (typeof process === 'undefined' || process.type === 'renderer' || process.browser === true || process.__nwjs) {
+ module.exports = require('./browser.js');
} else {
- module.exports = require('./node.js');
+ module.exports = require('./node.js');
}
@@ -1,10 +1,10 @@
/**
- * Detect Electron renderer process, which is node, but we should
+ * Detect Electron renderer / nwjs process, which is node, but we should
* treat as a browser.
*/